@@ -13,10 +13,6 @@ import * as React from 'react';
 import { avatarIcon, hamburgerIcon } from './icons';
 
 namespace CommandIDs {
-  /**
-   * Login using a given provider
-   */
-  export const login = '@quetz-frontend/menu-extension:login';
   /**
    * Logout the current user
    */
@@ -172,13 +168,12 @@ export class MenuButton extends ReactWidget {
                       src={profile.avatar_url}
                       shape="circle"
                       alt={`${profile.name.slice(0, 2).toLocaleUpperCase()}`}
-                    ></Avatar>
+                      style={{ width: '28px', height: '28px' }}
+                    />
                     <span className="hamburger-menu-text">Menu</span>
                     <hamburgerIcon.react
                       className="hamburger-icon"
                       tag="span"
-                      width="28px"
-                      height="28px"
                     />
                   </div>
                 )}
@@ -204,18 +199,6 @@ function activateMenu(app: QuetzFrontEnd): IMenu {
   menu.addClass('quetz-main-menu');
   const menuButton = new MenuButton(menu);
 
-  // Add commands
-  app.commands.addCommand(CommandIDs.login, {
-    label: (args) => `Sign in with ${args.provider}`,
-    isEnabled: (args) => !!args.provider && !!args.api,
-    isVisible: () => menu.profile === null,
-    execute: (args) => {
-      if (args.api) {
-        window.location.href = `/auth/${args.api}/login`;
-      }
-    },
-  });
-
   app.commands.addCommand(CommandIDs.logout, {
     label: 'Sign out',
     isVisible: () => menu.profile !== null,
